adonthell-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[adonthell-wastesedge-commits] Release_0-3-3 d521f72 22/50: CHANGED code


From: Kai Sterker
Subject: [adonthell-wastesedge-commits] Release_0-3-3 d521f72 22/50: CHANGED code so that only player is on hold when opening a window, not the whole map
Date: Mon, 25 Jul 2016 18:15:31 +0000 (UTC)

tag: Release_0-3-3
commit d521f72f61873c455bb69eeccb817f5955da4b0f
Author: Kai Sterker <address@hidden>
Commit: Kai Sterker <address@hidden>

    CHANGED code so that only player is on hold when opening a window, not the 
whole map
---
 scripts/schedules/control.py |   26 +++++++++++++-------------
 1 file changed, 13 insertions(+), 13 deletions(-)

diff --git a/scripts/schedules/control.py b/scripts/schedules/control.py
index 8280b79..c222963 100644
--- a/scripts/schedules/control.py
+++ b/scripts/schedules/control.py
@@ -1,7 +1,7 @@
 #
 #  $Id$
 #
-#  (C) Copyright 2001 Kai Sterker <address@hidden>
+#  (C) Copyright 2001/2002 Kai Sterker <address@hidden>
 #  Part of the Adonthell Project http://adonthell.linuxgames.com
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,8 @@ class control:
             #    with saving and background enabled
             menu = main_menu.main_menu (1, 1, 1)
 
-            # -- Stop updating the map
-            gamedata_engine ().set_update_map (0)
+            # -- Stop updating the player
+            gamedata_player ().set_schedule_active (0)
             gamedata_engine ().set_control_active (0)
 
             # -- open the main menu
@@ -38,7 +38,7 @@ class control:
                 gamedata_engine ().main_quit ()
             else:
                 # -- continue
-                gamedata_engine ().set_update_map (1)
+                gamedata_player ().set_schedule_active (1)
                 gamedata_engine ().set_control_active (1)
            
 
@@ -47,15 +47,15 @@ class control:
             s = data_screen (LOAD_SCREEN)
             s.set_activate (1) 
 
-            # -- Stop updating the map
-            gamedata_engine ().set_update_map (0)
+            # -- Stop updating the player
+            gamedata_player ().set_schedule_active (0)
             gamedata_engine ().set_control_active (0)
             
             # -- open the load screen
             gamedata_engine ().main (s, "load_screen")
             
             # -- continue
-            gamedata_engine ().set_update_map (1)
+            gamedata_player ().set_schedule_active (1)
             gamedata_engine ().set_control_active (1)
             
 
@@ -64,15 +64,15 @@ class control:
             s = data_screen (SAVE_SCREEN)
             s.set_activate (1) 
 
-            # -- Stop updating the map
-            gamedata_engine ().set_update_map (0)
+            # -- Stop updating the player
+            gamedata_player ().set_schedule_active (0)
             gamedata_engine ().set_control_active (0)
             
             # -- open the save screen
             gamedata_engine ().main (s, "save_screen")
 
             # -- continue
-            gamedata_engine ().set_update_map (1)
+            gamedata_player ().set_schedule_active (1)
             gamedata_engine ().set_control_active (1)
 
 
@@ -83,13 +83,13 @@ class control:
             c = console.console (globals ())
             c.set_activate (1)
 
-            # -- Stop updating the map
-            gamedata_engine ().set_update_map (0)
+            # -- Stop updating the player
+            gamedata_player ().set_schedule_active (0)
             gamedata_engine ().set_control_active (0)
 
             # -- open the console
             gamedata_engine ().main (c, "console")
 
             # -- continue
-            gamedata_engine ().set_update_map (1)
+            gamedata_player ().set_schedule_active (1)
             gamedata_engine ().set_control_active (1)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]